@@ -46,8 +46,12 @@
 #include "domdec_specatomcomm.h"
 
 #include <cassert>
+#include <cstdio>
 
 #include <algorithm>
+#include <array>
+#include <filesystem>
+#include <memory>
 
 #include "gromacs/domdec/dlb.h"
 #include "gromacs/domdec/domdec.h"
@@ -59,6 +63,7 @@
 #include "gromacs/math/vec.h"
 #include "gromacs/mdtypes/commrec.h"
 #include "gromacs/pbcutil/ishift.h"
+#include "gromacs/utility/arrayref.h"
 #include "gromacs/utility/fatalerror.h"
 #include "gromacs/utility/gmxassert.h"
 
@@ -439,7 +444,7 @@ int setup_specat_communication(gmx_domdec_t*             dd,
     {
         /* Pulse the grid forward and backward */
         const int ndir = (dd->dim[d] >= dd->unitCellInfo.npbcdim || dd->numCells[dd->dim[d]] > 2) ? 2 : 1;
-        int       nat_tot_prev = nat_tot_specat;
+        int nat_tot_prev = nat_tot_specat;
         for (int dir = ndir - 1; dir >= 0; dir--)
         {
             /* To avoid cost of clearing by resize(), we only increase size */
